@@ -6,10 +6,7 @@
 
 import re
 import textwrap
-try:
-    from urllib.request import FancyURLopener
-except ImportError:
-    from urllib import FancyURLopener
+
 try:
     import debug
     assert debug
@@ -18,16 +15,6 @@ except ImportError:
 
 import xml2rfc.log
 
-
-class StrictUrlOpener(FancyURLopener):
-    """ Override urllib opener to throw exceptions on 404s """
-    def __init__(self, *args, **kwargs):
-        FancyURLopener.__init__(self, *args, **kwargs)
-      
-    def http_error_default(self, url, fp, errcode, errmsg, headers):
-        raise IOError('Document not found ' + url)
-
-
 class MyTextWrapper(textwrap.TextWrapper):
     """ Subclass that overrides a few things in the standard implementation """
     def __init__(self, **kwargs):
@@ -61,7 +48,7 @@ class MyTextWrapper(textwrap.TextWrapper):
             # Tla with leading uppercase, and special cases
             # (Note: v1 spelled out Fig, Tbl, Mrs, Drs, Rep, Sen, Gov, Rev, Gen, Col, Maj and Cap,
             #  but those are redundant with the Tla regex.)
-            r'|([A-Z][a-z][a-z]|Eq|[Cc]f|vs|resp|viz|ibid|[JS]r|M[rs]|Messrs|Mmes|Dr|Profs?|St|Lt)\.'
+            r'|([A-Z][a-z][a-z]|Eq|[Cc]f|vs|resp|viz|ibid|[JS]r|M[rs]|Messrs|Mmes|Dr|Profs?|St|Lt|i\.e)\.'
             r')\Z' # trailing dot, end of group and end of chunk
             )
 
