@@ -35,6 +35,7 @@ class RawTextRfcWriter(BaseRfcWriter):
         self.iref_marker = 0    # Line number in buffer to write index to
         self.list_counters = {} # Maintain counters for 'format' type lists
         self.edit_counter = 0   # Counter for edit marks
+        # Set this to False to permit utf+8 output:
         self.ascii = True       # Enable ascii flag
         self.cref_counter = 0   # Counter for cref anchors
         self.cref_list = []
@@ -522,7 +523,10 @@ class RawTextRfcWriter(BaseRfcWriter):
             self.buf.extend([''] * blanklines)
             start_line = len(self.buf)
             # Format the input
-            lines = [line.rstrip() for line in text.expandtabs(4).split('\n')]
+            if "\t" in text:
+                xml2rfc.log.warn("Text %scontains tab characters.  These will be expanded, assuming a tab-size of 8." %
+                    (("around line %s "%source_line) if source_line else ""))
+            lines = [line.rstrip() for line in text.expandtabs().split('\n')]
             # Outdent if it helps anything
             longest_line = max(len(line.rstrip()) for line in lines)
             if (longest_line > self.width-indent):
@@ -1421,5 +1425,5 @@ class RawTextRfcWriter(BaseRfcWriter):
         else:
             file.write("\n"*5)
         for line in self.post_process_lines(self.output):
-            file.write(line.rstrip(" \t"))
+            file.write(line.rstrip(u" \t"))
             file.write("\n")
